fn modifier_priority(shortcuts: &[KeyboardShortcut]) -> u8Expand description
Determine the priority of the keyboard shortcuts based on their modifiers.
This is because egui’s shortcut handling ignores modifiers to some extent, so they must be checked in order of priority.
The egui design choice makes sense, since depending on keyboard you may not be able to press certain keys without modifiers, so one would like those symbols to match independent of modifiers. However, that leads to that the more modifiers, the earlier the short cut must be checked.